@@ -1,5 +1,5 @@
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __email__ = "horneds@gmail.com"
 __license__ = "GNU LGPL"
-__url__ = ' http://github.com/klen/pyserve',
+__url__ = 'http://github.com/klen/pyserve'
